/*
   LOCKKEYS_FR, traduit de dUFLP Lockkeys
   10 juillet 2010
    
   Description:
 
      A custom control written by Romain Strieff. Through the use
      of API calls, you can set or get the position of the 3 keys
      CAPSLOCK, SCROLLLOCK and NUMLOCK.


      Un contrle personnalis crit par Romain Strieff. Grce  l'utilisation 
      des appels de l'API, vous pouvez dfinir ou obtenir la position des 3 touches 
      CAPSLOCK, ScrollLock et NumLock.
 
   Programmers: 

      Romain Strieff 
 
   History: 
 
      03/01/2002 -- First appearance of this on the dBASE
                    newsgroups (posted by Romain)
      03/01/2002 -- Class made out of the original

   Instantiation: 
   Utilisation :

      set procedure to :dUFLP:LockKeys.cc additive
      k=new LockKeys()
      if k.GetScrollLock()
         k.SetScrollLock(false)
      endif
      if k.GetCapslock()
         k.SetCapsLock(false)
      endif

 
   Methods:
   Mthodes :

      GetCapsLock()
         Retourne la position relle de la touche de verrouillage majuscule
         Elle est appelle sans paramtre

      GetNumLock()
         Retourne la position relle de la touche Verr Num
         Elle est appelle sans paramtre

      GetScrollLock()
         Retourne la position relle de la touche ScrollLock
         Elle est appelle sans paramtre

      SetCapsLock(lOnOff)
         Positionne la touche de verrouillage majuscule sur on ou off
         Parametre logique TRUE pour ON et FALSE pour OFF

      SetNumLock(lOnOff)
         Positionne la touche Numlock sur on ou off
         Parametre logique TRUE pour ON et FALSE pour OFF

      SetScrollLock(lOnOff)
        Positionne la touche Scrolllock sur on ou off
        Parametre logique TRUE pour ON et FALSE pour OFF

      Release
         Effase la class de la mmoire

    Methodes protegees (instruction protect):
        Ceux-ci peuvent ne pas tre appel de l'extrieur, les mthodes
        ci-dessus les appellent

        Set()
           Positionne l'tat pour toutes les touches
        Get() 
           Indique l'tat actuel pour toutes les touches
*/

class LockKeys
   protect get, set
   //some constants that we need
   #ifndef KEYEVENTF_EXTENDEDKEY
     #define KEYEVENTF_EXTENDEDKEY 0x0001
   #endif
   #ifndef KEYEVENTF_KEYUP
      #define KEYEVENTF_KEYUP      0x0002
   #endif
   #ifndef VK_CAPITAL
      #define VK_CAPITAL           0x14
   #endif
   #ifndef VK_NUMLOCK
      #define VK_NUMLOCK           0x90
   #endif
   #ifndef VK_SCROLL
      #define VK_SCROLL            0x91
   #endif

   //and a couple of API functions
   if type("lGetKeyState") # "FP"
      extern cLogical lGetKeyState(cint) user32;
             from "GetKeyState"
   endif
   if type("keybd_event") # "FP"
      extern cVOID keybd_event;
             (cint, cint, cWORD, cWORD) user32
   endif


   // and here the methods, that's it 
   function SetCapslock(lOnOff)
      this.Set(VK_CAPITAL,lOnOff)
   return true  

   function SetScrolllock(lOnOff)
      this.Set(VK_SCROLL,lOnOff)
   return true
 

   function SetNumlock(lOnOff)
      this.Set(VK_NUMLOCK,lOnOff)
   return true

   function GetCapslock
   return this.Get(VK_CAPITAL)

   function GetScrolllock
   return this.Get(VK_SCROLL)

   function GetNumlock
   return this.Get(VK_NUMLOCK)

   function release
      release object this
   return

   //--------Set and Get functions----
   Function Get(nVirtualKey)
      sleep 0.15 //to make it 'stick'
   return lGetKeyState(nVirtualKey)

   Function Set
      parameters nVirtualKey,lOnOff
      //we switch only if it's in a different state

      if lGetKeyState(nVirtualKey) # lOnOff
         //Simulate Key Press
         keybd_event(nVirtualKey,;
               HTOI("45"),KEYEVENTF_EXTENDEDKEY,0)
         //Simulate Key Release
         keybd_event(nVirtualKey,;
               HTOI("45"),KEYEVENTF_EXTENDEDKEY+KEYEVENTF_KEYUP,0)
      endif
   return lGetKeyState(nVirtualKey)

   function test_existe

   	? msgbox("LockKeys_fr ouvert")

endclass
/*
    End of File: LockKeys.cc
*/
